function answer = vecIsInR2(a)
% vecIsInR2 - check to see if a is in R2
%
%   
% 
%   Syntax: 
%           answer = vecIsInR2(a)
%   Arguments: 
%           a - the vector to check
%   Returns: 
%           answer - true if a is in R2
%                    false if not in R2
%           
%   Description:
%
%           Check if a is in R2
%           
%           
%
%   See also:
%

%----------------------------------------------------------------------
%   Bugs:
%
%   Date created: 
%          990910
%   Author:
%          Marten Levenstam
%
%   Change history:
%
%                              +---------------------------------------+ 
%                              |     Matematik Kf/Kb 1999-2000         | 
%                              |     Copyright (c) 1999                | 
%                              |                                       | 
%                              |     Marten Levenstam                  | 
%                              |     Klas Samuelsson                   | 
%                              |     Dep. of Mathematics               | 
%                              |     Chalmers University of Technology | 
%                              |     S-412 96 Gothenburg               | 
%                              |     SWEDEN                            |     
%                              |     martenl@math.chalmers.se          |     
%                              |                                       |     
%------------------------------+---------------------------------------+
 true  = 1;
 false = 0;

 if(length(a) == 2)
   answer = true;
 else
   answer = false;
 end
 
